Learn R Programming

mailtoR (version 0.1.0)

use_mailtoR: Enable the MailtoUI javascript library

Description

The function activates the capabilities of the MailtoUI javascript library. The user needs to set it at the end of the shiny ui.

Usage

use_mailtoR()

Arguments

Value

called for the side effect of activating the MailtoUI library

Examples

Run this code
# NOT RUN {
# Put the function at the bottom of the ui

use_mailtoR()



# }

Run the code above in your browser using DataLab