powered by
The function activates the capabilities of the MailtoUI javascript library. The user needs to set it at the end of the shiny ui.
use_mailtoR()
called for the side effect of activating the MailtoUI library
# NOT RUN { # Put the function at the bottom of the ui use_mailtoR() # }
Run the code above in your browser using DataLab